@@ -1,4 +1,5 @@
 import pytest
+from pytest_mock import MockerFixture
 
 from accession.accession import AccessionWgbs
 from accession.analysis import Analysis
@@ -41,3 +42,28 @@ def test_accession_wgbs_make_gembs_alignment_qc(
     assert qc["general_reads"] == 3000
     assert qc["pct_general_reads"] == 50.0
     assert len(mock_accession_wgbs.get_attachment.mock_calls) == 2
+
+
+def test_accession_wgbs_get_preferred_default_qc_value(
+    mocker: MockerFixture, mock_accession_wgbs, gsfile
+):
+    mocker.patch.object(mock_accession_wgbs.analysis, "search_up")
+    mocker.patch.object(gsfile, "read_json", return_value={"general_reads": 30})
+    mocker.patch.object(
+        mock_accession_wgbs.analysis, "search_down", return_value=[gsfile]
+    )
+    result = mock_accession_wgbs.get_preferred_default_qc_value(gsfile)
+    mock_accession_wgbs.analysis.search_up.assert_called_once()
+    assert result == 30
+
+
+@pytest.mark.parametrize(
+    "qc_value,current_best_qc_value,expected", [(10.0, 1.0, True), (3.0, 10.0, False)]
+)
+def test_accession_wgbs_preferred_default_should_be_updated(
+    mock_accession_wgbs, qc_value, current_best_qc_value, expected
+):
+    result = mock_accession_wgbs.preferred_default_should_be_updated(
+        qc_value, current_best_qc_value
+    )
+    assert result is expected
